<?php
/*
 * A general DB utility class using PDO.
 * Copyright for this package of code: https://waggies.net/ws/copyright.txt.
 */

$classes = realpath(dirname(__FILE__) . '/../classes');
include_once "$classes/config.php";

class Db {
	public $dbh;
	public $prep;
	public $executeReturn;

	function __construct()
	{
	    $cfg = new WsConfig();
	    $this->dbh = new PDO("mysql:dbname=$cfg->dbname;host=$cfg->dbhost", $cfg->dbname, $cfg->dbpassword);
		$this->dbh->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_WARNING);
		$this->dbh->setAttribute(PDO::ATTR_EMULATE_PREPARES, false);
	}


	function prepare($stmt)
	{
		$this->prep = $this->dbh->prepare($stmt);
		return $this->prep;
	}


	function execute($arr = array()) {
		$this->executeReturn = $this->prep->execute($arr);
		return $this->executeReturn;
	}


	function exec($stmt) {
		$this->execReturn = $this->dbh->exec($stmt);
		return $this->execReturn;
	}


	function fetch($cfg, $where = '', $orderby = '') {
	    $stmt = "select * FROM $cfg->dbtablename";
	    if ($where) {
	        $stmt .= " WHERE $where";
	    }
	    if ($orderby) {
	        $stmt .= " ORDER BY $orderby";
	    }
	    $prep = $this->prepare($stmt);
	    $prep->execute();
	    $rows = $prep->fetch(PDO::FETCH_ASSOC);
	    return $rows;
	}


	function fetchLast($cfg) {
	    $stmt = 'select * FROM ' . $cfg->dbtablename . ' ORDER BY id DESC';
	    $prep = $this->prepare($stmt);
	    $prep->execute();
	    $rows = $prep->fetch(PDO::FETCH_ASSOC);
	    return $rows;
	}


	function fetchLastN($cfg, $n = 1) {
	    $stmt = "select * FROM $cfg->dbtablename  ORDER BY id DESC LIMIT $n";
	    $prep = $this->prepare($stmt);
	    $prep->execute();
	    $rows = $prep->fetchAll(PDO::FETCH_ASSOC);
	    return $rows;
	}


	function fetchAll($cfg, $where = '', $orderby = '') {
	    $stmt = "select * FROM $cfg->dbtablename";
	    if ($where) {
	        $stmt .= " WHERE $where";
	    }
	    if ($orderby) {
	        $stmt .= " ORDER BY $orderby";
	    }
	    $prep = $this->prepare($stmt);
	    $prep->execute();
	    $rows = $prep->fetchAll(PDO::FETCH_ASSOC);
	    return $rows;
	}


	function createTable($cfg, $items, $debug = false) {
	    // init the statement
	    $stmt = "CREATE TABLE $cfg->dbtablename (id INT NOT NULL AUTO_INCREMENT, ";

        // compose the list of columns, all text type
        foreach ($items as $key => $item) {
            $stmt .= "$key text,";
        }
        //$stmt = rtrim($stmt, ',');
        $stmt .= 'PRIMARY KEY (id)';
        $stmt .= ')';

        if ($debug) {
            return $stmt;
        }
        else {
            // execute it
            $prep = $this->prepare($stmt);
            $result = $this->execute();
            return $result;
        }
	}


	function dropTable($cfg) {
	    print("<p>Dropping table '$cfg->dbtablename'...</p>");
	    $prep = $this->prepare("DROP TABLE $cfg->dbtablename");
	    $result = $this->execute();
	    return $result;
	}
}
